;---------------------------------------------------
;
; ISN AutoIt Studio Testproject 4 (build 10.06.2023)
; by ISI360 (Christian Faderl), created with ISN Autoit Studio
;
;---------------------------------------------------
; Welcome in the ISN AutoIt Studio Testproject 4!
; This example project will demonstrate the "write all handles of the GUI / controls into a map variable" feature of the ISN Formstudio.
; As the name of the feature suggests, the Formstudio will write all control handles of a form to a map variable. With this you can
; easily generate GUIs in runtime and easy access all the different handles of the controls without the need of global declarations. 
;
; Stuff in a map variable can be accessed by two different "writing styles":
; Variant 1 (Array like): $Map["MainForm"] 
; Variant 2 (Object like): $Map.MainForm 
; -> Both have exactly the same functionality!
;
; NOTE: This example needs ISN AutoIt Studio version 1.15 AND AutoIt version 3.3.16.0 or newer to work correctly!
;---------------------------------------------------
;
; What this script does:
; - Creats a simple demo gui, with the setting "write all handles of the GUI / controls into a map variable" enabled in the gui properties.
; - Shows some examples how to interact with various controls in this new mode, using the two possible writing styles.
;
; Run this project with the F5 key. (Or choose Project -> Test project from the menubar)
; Happy testing!
;---------------------------------------------------

;Includes
#include "Forms\MainForm.isf" ;Include the MainForm.isf 

;Make this script high DPI aware
;AutoIt3Wrapper directive for exe files, DllCall for au3/a3x files
#AutoIt3Wrapper_Res_HiDpi=y
If not @Compiled then DllCall("User32.dll", "bool", "SetProcessDPIAware")

;Let´s load the GUI (with "write all handles of the GUI / controls into a map variable" enabled), and assign the returned map to a new variable ($MainFormMap)
Global $MainFormMap = _MainForm()

;Let´s display the GUI. We use the returned Map and the Key "MainForm" to get the handle of the GUI window ("Array like" writing style)
GUISetState(@SW_SHOW, $MainFormMap["MainForm"])

;Let´s change the Text of the label in the middle of the GUI
GUICtrlSetData($MainFormMap["textMiddle"], "The new text was successfully changed! (Case 1)")

;Let´s change the Text again, but this time we use the object like writing style to to access the map
GUICtrlSetData($MainFormMap.textMiddle, "The new text was successfully changed! (Case 2)")

;Display a MsgBox, with the content of "textMiddle" (here we use again the "object" writing style)
MsgBox(64,"Content of textMiddle",Guictrlread($MainFormMap.textMiddle),0, $MainFormMap.MainForm)

;Set progressbar to 50%
GUICtrlSetData($MainFormMap.progress, 50)

While 1
	Switch GUIGetMsg()
		Case $GUI_EVENT_CLOSE, $MainFormMap["buttonRight"]
			ExitLoop

	EndSwitch
WEnd

